DSLoggingProvider class abstract
Logging provider interface for DartStream. This abstract class defines the standard interface for all logging providers.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → Future< void> - Dispose of the provider and release any resources
-
error(
String message, {dynamic error, StackTrace? stackTrace, Map< String, dynamic> ? context}) → void - Log an error message, optionally with an exception and stack trace
-
flush(
) → Future< void> - Flush any buffered logs
-
info(
String message, {Map< String, dynamic> ? context}) → void - Log an informational message
-
initialize(
Map< String, dynamic> config) → Future<void> - Initialize the logging provider with configuration settings
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
warn(
String message, {Map< String, dynamic> ? context}) → void - Log a warning message
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited