DSLoggingProviderMetadata class
Metadata for registered logging providers
Constructors
-
DSLoggingProviderMetadata({required String type, String? region, Map<
String, dynamic> ? additionalMetadata})
Properties
-
additionalMetadata
→ Map<
String, dynamic> ? -
Additional provider-specific settings
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- region → String?
-
Optional region or environment
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
e.g. 'console', 'stackdriver', etc.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited